import unittest
from r3c0n import Clean as clean

class TestCleanup(unittest.TestCase):
    """Test the formatting of different subdomain outputs from engines.

    Args:
        unittest.TestCase: A test case object to be run

    Asserts:
        bool: Whether the function cleans the output successfully
        Example: ['https://example.com'] -> ['example.com']
    """
    def test_subdomain_cleanup(self):
        """
        Test the protocol prefix in the output
        """
        example_list = ['https://example.com', 'http://example.com']
        result_1 = clean.cleanup(example_list[0])
        result_2 = clean.cleanup(example_list[1])
        self.assertEqual(result_1, ['example.com'])
        self.assertEqual(result_2, ['example.com'])

if __name__ == '__main__':
    unittest.main()


import sys
from scripts import anubis
import utils.viewer as viewer

def main():
    if len(sys.argv) > 1:
        subdomains = anubis.anubis_script(str(sys.argv[1]))
        viewer.show(subdomains)
    else:
        help = 'HELP SECTION'
        viewer.show(help)

if __name__ == "__main__":
    main()


import requests
import random

def GET_UA():
    uastrings = [
        "Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.111 Safari/537.36",\
        "Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.72 Safari/537.36",\
        "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10) AppleWebKit/600.1.25 (KHTML, like Gecko) Version/8.0 Safari/600.1.25",\
        "Mozilla/5.0 (Windows NT 6.1; WOW64; rv:33.0) Gecko/20100101 Firefox/33.0",\
        "Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.111 Safari/537.36",\
        "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.111 Safari/537.36",\
        "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_5) AppleWebKit/600.1.17 (KHTML, like Gecko) Version/7.1 Safari/537.85.10",\
        "Mozilla/5.0 (Windows NT 6.1; WOW64; Trident/7.0; rv:11.0) like Gecko",\
        "Mozilla/5.0 (Windows NT 6.3; WOW64; rv:33.0) Gecko/20100101 Firefox/33.0",\
        "Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.104 Safari/537.36"\
        ]
 
    return random.choice(uastrings)

def anubis_script(domain):
    """Returns the list of subdomains from the Anuibis Database.

    Args:
        domain: An inscope domain in which the subdomains are required.
    Returns:
        A list of subdomains extracted from the Anubis database.
    Raises:
        RequestError: Raised on wrong request type.
        HTTPError: Raised on malformed HTTP request.
        ConnectionError: Raised when fails to connect to the server.
        TimeoutError: Raised when request takes too long to come back.
    """
    anubis = []
    headers = {"User-Agent": GET_UA(), "Content-Type": "application/json"}
    try:
        res = requests.get("https://jldc.me/anubis/subdomains/" + domain, headers=headers, timeout=10)
        res.raise_for_status()
        stripped_response = res.text.strip().split(",")
        for id, res in enumerate(stripped_response):
            res = res.replace('"', '')
            if id == 0:
                res = res[1:]
            if id == len(stripped_response)-1:
                res = res[:-1]
            anubis.append(res)
        return anubis
    except requests.exceptions.RequestException as err:
        print ("Request Exception:", err)
    except requests.exceptions.HTTPError as errh:
        print ("HTTP Error:", errh)
    except requests.exceptions.ConnectionError as errc:
        print ("Connection Error:", errc)
    except requests.exceptions.Timeout as errt:
        print ("Timeout Error:", errt) 
    return []


import pathlib
from setuptools import setup

# The directory containing this file
PATH = pathlib.Path(__file__).parent

# The text of the README file
README = (PATH / "README.md").read_text()

VERSION="1.0.3"
DESCRIPTION="A tool for performing reconnaissance on web targets in Python."
LONG_DESCRIPTION="A tool for finding subdomain and directory information for various web targets."

setup(
    name='r3c0n',
    version=VERSION,
    license='MIT',
    license_files=["LICENSE"],
    author='Gacoka Mbui',
    author_email='<markgacoka@gmail.com>',
    description=DESCRIPTION,
    long_description=README,
    long_description_content_type='text/markdown',
    url="https://github.com/markgacoka/r3c0n",
    download_url="https://github.com/markgacoka/r3c0n/releases",
    packages=['r3c0n'],
    include_package_data=True,
    install_requires=['yarl==1.7.2'],
    entry_points={
        "console_scripts": [
            "r3c0n=r3c0n.__main__:main",
            "scripts=r3c0n.scripts",
            "utils=r3c0n.utils"
        ]
    },
    keywords='cybersecurity, reconnaissance, scanning, automation',
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Topic :: Security"
    ]
)


import yarl
from typing import List

class Clean:
    def cleanup(subdomain_lst: List[str]) -> List[str]:
        """Returns a standardized version of subdomains

        Args:
            subdomain_lst: A list of subdomains from different engines

        Returns:
            A list of correctly formatted subdomains
        """
        clean_lst = []
        for domain in subdomain_lst:
            if domain.strip() == '' or domain == None:
                pass
            if '\n' in domain:
                intermediary = domain.split('\n')
                for i in intermediary:
                    clean_lst.append(i)
            else:
                clean_lst.append(domain)
        for idx, subdomain in enumerate(clean_lst):
            if subdomain.startswith('https://'):
                if yarl.URL(subdomain).path_qs != '' or  yarl.URL(subdomain).path_qs != '/':
                    clean_lst[idx] = str(yarl.URL(subdomain).origin())[8:].strip()
            elif subdomain.startswith('http://'):
                if yarl.URL(subdomain).path_qs != '' or yarl.URL(subdomain).path_qs != '/':
                    clean_lst[idx] = str(yarl.URL(subdomain).origin())[7:].strip()
            else:
                if subdomain.strip() != '' and subdomain != None:
                    subdomain_full = 'http://' + str(subdomain)
                    subdomain_yarl = yarl.URL(subdomain_full)
                    if subdomain_yarl.path_qs != '' or subdomain_yarl.path_qs != '/':
                        clean_lst[idx] = str(subdomain_yarl.origin())[7:].strip()
        return list(filter(None, set(clean_lst)))